# CasemanagerClient::DefaultApi

All URIs are relative to *http://casemanager.dev.cmmint.net*

Method | HTTP request | Description
------------- | ------------- | -------------
[**case_items_post**](DefaultApi.md#case_items_post) | **POST** /case_items | Creates or updates case items
[**cases_key_events_post**](DefaultApi.md#cases_key_events_post) | **POST** /cases/{key}/events | Apply an event to a case.
[**list_patients**](DefaultApi.md#list_patients) | **GET** /patients | List all Patients with Cases. Allows optional search parameters; search parameters are ANDed together.
[**show_case**](DefaultApi.md#show_case) | **GET** /cases/{key} | Get the details of a specific case


# **case_items_post**
> case_items_post(v, source_type, source_identifier, opts)

Creates or updates case items

### Example
```ruby
# load the gem
require 'casemanager_client'
# setup authorization
CasemanagerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = CasemanagerClient::DefaultApi.new
v = 'v_example' # String | Version of the CaseManager API. Required to be `v=root_v1`
source_type = 'source_type_example' # String | The type of item being updated or created
source_identifier = 'source_identifier_example' # String | The ID or key of the item
opts = {
  case_key: 'case_key_example' # String | If this item is known to belong to a case, the case key can be provided
}

begin
  #Creates or updates case items
  api_instance.case_items_post(v, source_type, source_identifier, opts)
rescue CasemanagerClient::ApiError => e
  puts "Exception when calling DefaultApi->case_items_post: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **v** | **String**| Version of the CaseManager API. Required to be &#x60;v&#x3D;root_v1&#x60; | 
 **source_type** | **String**| The type of item being updated or created | 
 **source_identifier** | **String**| The ID or key of the item | 
 **case_key** | **String**| If this item is known to belong to a case, the case key can be provided | [optional] 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **cases_key_events_post**
> cases_key_events_post(v, user_id, event_type, key)

Apply an event to a case.

### Example
```ruby
# load the gem
require 'casemanager_client'
# setup authorization
CasemanagerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = CasemanagerClient::DefaultApi.new
v = 'v_example' # String | Version of the CaseManager API. Required to be `v=sudo_v1`
user_id = 56 # Integer | the CMM2 T_Users ID
event_type = 'event_type_example' # String | The type of event to be applied to the case
key = 'key_example' # String | The key of the case that the event applies to

begin
  #Apply an event to a case.
  api_instance.cases_key_events_post(v, user_id, event_type, key)
rescue CasemanagerClient::ApiError => e
  puts "Exception when calling DefaultApi->cases_key_events_post: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **v** | **String**| Version of the CaseManager API. Required to be &#x60;v&#x3D;sudo_v1&#x60; | 
 **user_id** | **Integer**| the CMM2 T_Users ID | 
 **event_type** | **String**| The type of event to be applied to the case | 
 **key** | **String**| The key of the case that the event applies to | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined



# **list_patients**
> Array&lt;PatientWithCases&gt; list_patients(user_id, v, opts)

List all Patients with Cases. Allows optional search parameters; search parameters are ANDed together.

### Example
```ruby
# load the gem
require 'casemanager_client'
# setup authorization
CasemanagerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = CasemanagerClient::DefaultApi.new
user_id = 56 # Integer | the CMM2 T_Users ID
v = 'v_example' # String | Version of the CaseManager API. Required to be `v=sudo_v1`
opts = {
  first_name: 'first_name_example', # String | Search by patient's first name (substring search)
  middle_name: 'middle_name_example', # String | Search by patient's middle name (substring search)
  last_name: 'last_name_example', # String | Search by patient's last name (substring search)
  date_of_birth: 'date_of_birth_example', # String | Search by patient's date of birth (exact match)
  zipcode: 'zipcode_example' # String | Search by patient's zipcode (exact match)
}

begin
  #List all Patients with Cases. Allows optional search parameters; search parameters are ANDed together.
  result = api_instance.list_patients(user_id, v, opts)
  p result
rescue CasemanagerClient::ApiError => e
  puts "Exception when calling DefaultApi->list_patients: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_id** | **Integer**| the CMM2 T_Users ID | 
 **v** | **String**| Version of the CaseManager API. Required to be &#x60;v&#x3D;sudo_v1&#x60; | 
 **first_name** | **String**| Search by patient&#39;s first name (substring search) | [optional] 
 **middle_name** | **String**| Search by patient&#39;s middle name (substring search) | [optional] 
 **last_name** | **String**| Search by patient&#39;s last name (substring search) | [optional] 
 **date_of_birth** | **String**| Search by patient&#39;s date of birth (exact match) | [optional] 
 **zipcode** | **String**| Search by patient&#39;s zipcode (exact match) | [optional] 

### Return type

[**Array&lt;PatientWithCases&gt;**](PatientWithCases.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **show_case**
> CaseWithPatient show_case(key, user_id, v)

Get the details of a specific case

### Example
```ruby
# load the gem
require 'casemanager_client'
# setup authorization
CasemanagerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = CasemanagerClient::DefaultApi.new
key = 'key_example' # String | 
user_id = 56 # Integer | the CMM2 T_Users ID
v = 'v_example' # String | Version of the CaseManager API. Required to be `v=sudo_v1`

begin
  #Get the details of a specific case
  result = api_instance.show_case(key, user_id, v)
  p result
rescue CasemanagerClient::ApiError => e
  puts "Exception when calling DefaultApi->show_case: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key** | **String**|  | 
 **user_id** | **Integer**| the CMM2 T_Users ID | 
 **v** | **String**| Version of the CaseManager API. Required to be &#x60;v&#x3D;sudo_v1&#x60; | 

### Return type

[**CaseWithPatient**](CaseWithPatient.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



